==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/Input/mpc/translations/mpc_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="63"/>
        <source>Musepack Plugin</source>
        <translation>Módulo Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="65"/>
        <source>Musepack Files</source>
        <translation>Archivos Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="134"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Acerca del módulo de audio Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="135"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Módulo de audio Musepack para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="136"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/mpc/translations/mpc_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="53"/>
        <source>Musepack Plugin</source>
        <translation>Módulo Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="55"/>
        <source>Musepack Files</source>
        <translation>Archivos Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="119"/>
        <source>About Musepack Audio Plugin</source>
        <translation>Acerca del módulo de audio Musepack</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="120"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Módulo de audio Musepack para Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="121"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
